pub enum Commands {
Mutate(MutationCommandConfig),
Config(ConfigCommandConfig),
Clean(MutationCommandConfig),
}Variants
Mutate(MutationCommandConfig)
Mutate the files in the given path If no path is given, the current directory will be used A csv file will be generated along with a html table
Config(ConfigCommandConfig)
Display help text on how to setup the config file or create a config file in the current directory
Clean(MutationCommandConfig)
Clean the mutant-kraken-dist directory This will delete all files in the directory This is useful if you want to remove all the files