pub enum MutationOperators {
Show 15 variants
ArithmeticReplacementOperator,
UnaryRemovalOperator,
LogicalReplacementOperator,
RelationalReplacementOperator,
AssignmentReplacementOperator,
UnaryReplacementOperator,
NotNullAssertionOperator,
ElvisRemoveOperator,
ElvisLiteralChangeOperator,
LiteralChangeOperator,
ExceptionChangeOperator,
WhenRemoveBranchOperator,
RemoveLabelOperator,
FunctionalBinaryReplacementOperator,
FunctionalReplacementOperator,
}Variants
ArithmeticReplacementOperator
Replaces an arithmetic operator with a different arithmetic operator
UnaryRemovalOperator
Removes a unary operator
LogicalReplacementOperator
Replaces a logical operator with a different logical operator
RelationalReplacementOperator
Replaces a relational operator with a different relational operator
AssignmentReplacementOperator
Replaces an assignment operator with a different assignment operator
UnaryReplacementOperator
Replaces a unary operator with a different unary operator
NotNullAssertionOperator
Replaces a not null assertion operator with a different not null assertion operator
ElvisRemoveOperator
Removes an elvis operator
ElvisLiteralChangeOperator
Changes the literal of an elvis operator
LiteralChangeOperator
Changes the literal of a literal
ExceptionChangeOperator
Changes the exception thrown
WhenRemoveBranchOperator
Removes a branch from the when statement if the statement has more than one branch
RemoveLabelOperator
Removes a label when continuing, breaking, or returning
FunctionalBinaryReplacementOperator
Changes first() to last() and vice versa or find() to findLast() and vice versa
FunctionalReplacementOperator
Changes Any() to All() or None() and vice versa or ForEach() to Map() or Filter() and vice versa
Implementations